#
# spec file for package pam-modules
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %{suse_version} >= 1100
%define enable_selinux 1
%else
%define enable_selinux 0
%endif

Name:           pam-modules
Summary:        Additional PAM Modules
License:        BSD-3-Clause and GPL-2.0
Group:          System/Libraries
Version:        12.1
Release:        27.2
#
Source0:        pam_unix2-2.9.1.tar.bz2
Source1:        pam_pwcheck-3.13.tar.bz2
Source2:        pam_homecheck-2.0.tar.bz2
Source3:        default.passwd
Source6:        baselibs.conf
Source50:       dlopen.sh
Patch0:         0003-use-crypt_gensalt_rn-from-glibc.diff
Patch1:         0004-add-workarounds-for-blowfish-signedness-bug.diff
Patch2:         pam_unix2-glibc216.patch
Patch3:         pam_unix2-selinux.patch
Patch4:         pam-modules-automake.patch
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         permissions
BuildRequires:  cracklib-devel
BuildRequires:  libtool
BuildRequires:  pam-devel
%if %{enable_selinux}
BuildRequires:  libselinux-devel
%endif
BuildRequires:  pkgconfig(libnsl)

%description
PAM (Pluggable Authentication Modules) is a system security tool that
allows system administrators to set authentication policies without
having to recompile programs that do authentication.

This package contains additional, obsolete PAM Modules sometimes
needed for migration: pam_unix2 and pam_pwcheck


%prep
%setup -q -c %{name} -b1 -b2
pushd pam_unix2-*
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
popd
%patch4
%build
pushd pam_unix2-*
gettextize -f
popd
for i in * ; do
  cd $i;
  autoreconf -fiv
  %configure --enable-selinux \
		--libdir=/%{_lib}
  make %{?_smp_mflags}
  cd ..
done

%install
mkdir -p $RPM_BUILD_ROOT/sbin
install -d -m 755 $RPM_BUILD_ROOT%{_libdir}
for i in * ; do
  cd $i;
  make DESTDIR=$RPM_BUILD_ROOT install
  cd ..
done
#
# Remove stuff we don't wish to have now:
#
rm -rf $RPM_BUILD_ROOT/usr/{include,lib}
rm -rf $RPM_BUILD_ROOT/%{_lib}/security/*.la
# Check for module problems.  Specifically, check that every module we just
# installed can actually be loaded by a minimal PAM-aware application.
export CC=%__cc
for module in $RPM_BUILD_ROOT/%{_lib}/security/pam*.so ; do
   if ! sh $RPM_SOURCE_DIR/dlopen.sh -lpam -ldl ${module} ; then
      exit 1
   fi
done
#
# Install READMEs of PAM modules
#
DOC=$RPM_BUILD_ROOT%{_defaultdocdir}/pam
mkdir -p $DOC/modules
for i in pam_*/README ; do
  cp -fpv ${i} $DOC/modules/README.`dirname ${i}`
done
# Replace default/passwd file
install -m 644 %SOURCE3 $RPM_BUILD_ROOT/etc/default/passwd
# Find lang files
%{find_lang} pam_unix2
%{find_lang} pam_pwcheck pam_unix2.lang

%files -f pam_unix2.lang
%defattr(-,root,root,755)
%doc %{_defaultdocdir}/pam
%attr(644,root,root) %config(noreplace) /etc/default/passwd
%attr(755,root,root) /%{_lib}/security/pam_homecheck.so
%attr(755,root,root) /%{_lib}/security/pam_pwcheck.so
%attr(755,root,root) /%{_lib}/security/pam_unix2.so
%attr(644,root,root) %doc %{_mandir}/man8/pam_pwcheck.8.gz
%attr(644,root,root) %doc %{_mandir}/man8/pam_unix2.8.gz

%changelog
* Thu Apr 14 2016 kukuk@suse.de
- remove unix2_chkpwd (moved to pam), to be able to drop this
  obsolete package in the near future.
* Mon Apr 11 2016 kukuk@suse.de
- Link against external (non-glibc) libnsl.
* Tue Mar 15 2016 pcerny@suse.com
- unix2_chkpwd helper
  * read delay on failure from login.defs (FAIL_DELAY)
  * decrease default "password-cracker deterrent" delay to 100ms
* Mon Aug 18 2014 kukuk@suse.de
- Remove duplicate lines from default/passwd [bnc#892316]
* Mon Jul 28 2014 kukuk@suse.de
- Adjust description, this are no longer the default PAM modules.
* Thu Jul  4 2013 schwab@suse.de
- crypt_gensalt moved to separate library libowcrypt (fate#314945)
* Thu Mar  7 2013 cfarrell@suse.com
- license update: BSD-3-Clause and GPL-2.0
  See e.g. /src/copy_xattr.c
* Thu Feb 28 2013 crrodriguez@opensuse.org
- pam-modules-automake.patch: Fix build with new automake
  there is nop AM_CONFIG_HEADER anymore.
  * Modernize use of autoconf, use current macros.
* Wed Nov 14 2012 kukuk@suse.de
- Add /etc/default/passwd for pam_unix2.so, was removed with
  pwdutils drop.
* Mon Sep  3 2012 idonmez@suse.com
- Add pam_unix2-selinux.patch: selinux_check_access is now a public
  function provided by selinux. Use pu_selinux_check_access to fix
  conflict.
* Sun Jul 22 2012 aj@suse.de
- Do not use private glibc macros - those are not available with
  glibc 2.16 anymore.
* Wed Jul 11 2012 vcizek@suse.com
- fixed misspelled binary name in unix2_chkpwd.8 (bnc#770896)
* Tue Apr  3 2012 kukuk@suse.com
- Update to pam_unix2 2.9.1 (merge of patches)
* Tue Dec 13 2011 lnussel@suse.de
- use thread local store for logindefs list (bnc#735220)
* Wed Dec  7 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc, %%configure macros
* Thu Sep 22 2011 kukuk@suse.de
- Update to pam_unix2 2.9.0: Add support for
  /etc/security/uname26.conf, which allows to define a set of
  users which will only see kernel 2.6.40 on a linux 3.x system.
* Wed Aug 31 2011 mc@suse.de
- unix2_chkpwd should call pam_acct_mgmt (bnc#707645, CVE-2011-3172)
- unix2_chkpwd should only sleep 5 sec on failed logins
* Thu Jul  7 2011 lnussel@suse.de
- add compat mode options to deal with crypt_blowfish signedness bug
  (bnc#700876)
* Wed Jul  6 2011 lnussel@suse.de
- use crypt_gensalt_rn from glibc instead of built-in code
* Wed Jun 29 2011 kukuk@suse.de
-Update pam_unix2 to version 2.8.2
  - Fix the last patch
* Wed May 25 2011 kukuk@suse.de
- Update pam_pwcheck to version 3.13
  - work without xcrypt installed
  - update translations
* Wed May 18 2011 kukuk@suse.de
- Update pam_unix2 to version 2.8.1
  - better error handling
* Thu May 12 2011 kukuk@suse.de
- Remove pam_make
- Remove xcrypt from BuildRequires
* Wed May 11 2011 kukuk@suse.de
- Update pam_unix2 to version 2.8
  - Remove xcrypt dependency
* Tue Mar  1 2011 mc@suse.de
- fix pam_unix2 man page (bnc#655138)
* Tue Mar  1 2011 kukuk@suse.de
- Update pam_unix2 to version 2.7.5
  - Fix setting of password if no one was set before
* Wed Aug 11 2010 kukuk@suse.de
- Update pam_unix2 to version 2.7.4
  - Minor bugfix in expire handling [bnc#629024]
  - Add new translation for gl
  - Update translations
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Dec  8 2009 jengelh@medozas.de
- enable parallel building
* Fri Nov 13 2009 chris@computersalat.de
- spec mods
  o sorted TAGS
  o fixed build for < 1100
    enable_selinux 1 >= 1100
    enable_selinux 0 < 1100
* Mon Jul 20 2009 kukuk@suse.de
- Update pam_unix2 to version 2.7.3:
  - honour locked shadow accounts [bnc#433008]
  - Sync passwd/shadow file to disk [bnc#520125]
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Mon Jun 15 2009 kukuk@suse.de
- Update pam_pwcheck to fix some configure bugs
* Mon Feb  9 2009 kukuk@suse.de
- Update translations
- pam_unix2: Fix password change in regard to PRELIM not alwyas
  executed.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Dec  2 2008 mc@suse.de
- let unix2_chkpwd call pam_setcred(PAM_REFRESH_CRED)
  (bnc#420060)
* Fri Nov 21 2008 kukuk@suse.de
- pam_pwcheck: Fix handling of empty passwords [bnc#447483]
* Fri Nov 21 2008 kukuk@suse.de
- Update translations
* Thu Oct 16 2008 kukuk@suse.de
- Workaround for system account locking problem [bnc#435874]
* Wed Oct  8 2008 kukuk@suse.de
- Update pam_unix2 to version 2.7.0:
  - Add support for new passwords using SHA256 and SHA512
  - Fix lock account handling for shadow passwords [bnc#433008]
* Fri Sep  5 2008 kukuk@suse.de
- pam_pwcheck 3.12.1: Don't export local symbols [bnc#421921]
* Thu Sep  4 2008 kukuk@suse.de
- pam_pwcheck 3.12: Remove deprecated code
* Thu Aug 28 2008 kukuk@suse.de
- pam_unix2: make session logging more verbose
* Wed Aug 20 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Mon Aug 11 2008 mc@suse.de
- fix password change. Compare stored with entered password
  if PAM_CHANGE_EXPIRED_AUTHTOK flag is set.
  (bnc#414783)
* Fri May 23 2008 kukuk@suse.de
- Update translations for pam_unix2 and pam_pwcheck
* Fri Apr 11 2008 kukuk@suse.de
- Update pam_unix2 and pam_pwcheck:
  - Adjust for new libxcrypt [bnc#378755]
  - Update translations
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Nov 26 2007 mc@suse.de
- fix open call
* Mon Aug 27 2007 kukuk@suse.de
- Update translations of pam_unix2.so and pam_pwcheck.so
* Tue Feb 13 2007 lnussel@suse.de
- delay reading of password in unix2_chkpwd until pam actually
  requests a PAM_PROMPT_ECHO_OFF prompt (#244723)
* Wed Jan 24 2007 mc@suse.de
- add %%verify_permissions for /sbin/unix2_chkpwd
  [#237625]
* Wed Jan 17 2007 lnussel@suse.de
- install unix2_chkpwd setuid root instead of setgid shadow (#216816)
* Wed Dec 20 2006 kukuk@suse.de
- Update translations for pam_pwcheck
- Update to pam_unix2 2.3:
  - Correct fix for [#221233]
  - Add translations for bg and hr
  - Update translations for es, it and ja
* Thu Nov 16 2006 mc@suse.de
- prevent guessing of non-existing accounts [#221233]
* Fri Nov 10 2006 kukuk@suse.de
- Update to pam_unix2 2.1.1:
  - Fix wrong NULL pointer check [#219112]
  - Update pt_BR translation
  - Add translation for uk
* Mon Nov  6 2006 kukuk@suse.de
- Update to pam_unix2 2.1: Fix handling of empty passwords (found
  when evaluating [#216817]), update translations
- Update to pam_pwcheck 3.10.1: Docu fixes and translations update
* Wed Oct 25 2006 kukuk@suse.de
- Update to pam_make 1.2: Don't override CFLAGS, fix path to make
* Fri Sep 29 2006 kukuk@suse.de
- Fix seg.fault in pam_unix2 [#208277]
* Fri Sep 15 2006 kukuk@suse.de
- Update to pam_pwcheck 3.10 (Remove pam_pwcheck.conf support)
- Update to pam_unix2 2.0 (Remove pam_unix2.conf support)
- Remove pam_unix.so hardlink
* Tue Sep 12 2006 mc@suse.de
- remove pam_devperm; this functionality is done by resmgr
* Mon Sep  4 2006 kukuk@suse.de
- Remove obsolete pam_unix2.conf and pam_pwcheck.conf files.
* Tue Aug 22 2006 kukuk@suse.de
- Update pam_pwcheck and pam_unix2 (drop obsolete arguments, fix
  stacking with other modules).
* Thu Aug 10 2006 mc@suse.de
- move pam_chroot, pam_mktemp, pam_passwdqc and  pam_userpass
  in own RPMs
* Mon Aug  7 2006 kukuk@suse.de
- Remove obsolete READMEs
* Wed May 17 2006 schwab@suse.de
- Don't strip binaries.
- Fix executable stack.
* Tue Apr 11 2006 kukuk@suse.de
- Update translations of pam_unix2 and pam_pwcheck
* Mon Mar  6 2006 kukuk@suse.de
- Update more translations of pam_pwcheck
* Thu Mar  2 2006 kukuk@suse.de
- Update hu/km translations for pam_unix2 and pam_pwcheck
* Mon Feb 20 2006 kukuk@suse.de
- Update/add translations for pam_unix2 and pam_pwcheck
* Mon Feb  6 2006 kukuk@suse.de
- pam_unix2: Fix crash in NIS+ code
- pam_unix2: Update pt, nb and nl translations
* Fri Jan 27 2006 kukuk@suse.de
- Update german translation for pam_unix2
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 kukuk@suse.de
- pam_make: Add manual page
* Thu Jan 19 2006 kukuk@suse.de
- pam_make: Update to version 1.0 (add translations, rewrote to
  work with setuid binaries like passwd).
- pam_unix2: Call other modules before user sanity checks [#143507]
* Thu Jan 19 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan 17 2006 kukuk@suse.de
- Update pam_unix2 to version 1.29: Don't abort if config file does
  not exist.
* Sat Jan 14 2006 kukuk@suse.de
- Update pam_pwcheck to version 3.4 (new translations)
- Update pam_unix2 to version 1.28 (new translations)
- Remove pam_resmgr
* Thu Jan 12 2006 kukuk@suse.de
- Update pam_passwdqc to version 1.0.2
- Update pam_userpass to version 1.0
- Update pam_chroot to version 0.9.1
- Update pam_pwcheck to version 3.3
- Update resmgr code
* Sat Dec 17 2005 kukuk@suse.de
- Workaround rpm 4.4.2
* Mon Dec 12 2005 kukuk@suse.de
- Update to pam_unix2-1.27 (merge of all translations and patches)
* Mon Dec  5 2005 kukuk@suse.de
- Disable SELinux
* Thu Nov 24 2005 kukuk@suse.de
- pam_pwcheck: Update to version 3.2
- pam_resmgr: Update to version 0.9.8_SVNr63
- pam_devperm: Remove restoring of permissions after reboot
* Wed Oct 26 2005 schubi@suse.de
- fixed typo in logindevperm Bugzilla #117664
* Tue Oct 18 2005 schwab@suse.de
- Fix namespace pollution.
* Mon Oct 10 2005 kukuk@suse.de
- Compile pam_unix2 with -fno-strict-aliasing
* Mon Oct 10 2005 kukuk@suse.de
- Update pam_homecheck and pam_pwcheck
- Remove pam_wheel
* Mon Oct 10 2005 schubi@suse.de
- included syslog.h
* Sat Sep  3 2005 kukuk@suse.de
- Fix permissions of manual pages [#114849]
* Fri Sep  2 2005 schubi@suse.de
- Added bg nl pl translations
- Bug 114673 - logindevperm shouldn't touch lirc 'devices'
* Tue Aug 30 2005 kukuk@suse.de
- pam_pwcheck: Fix storing of old passwords longer then
  8 characters [#114016]
- Update unix2_pwcheck manual page
* Wed Aug 24 2005 kukuk@suse.de
- pam_unix2: Print warning if the priviliges are not sufficient to
  get the passwords.
* Mon Aug 22 2005 schubi@suse.de
- pam_mktemp updated (version 1.0.1)
* Mon Aug 22 2005 schubi@suse.de
- Added de es fr it ja nb pt_BR zh* translations
* Mon Aug 15 2005 schubi@suse.de
- Added hu, pa and pt translations
* Tue Aug  9 2005 schubi@suse.de
- Bug #99689 : Changing OpenLDAP password not possible with KDM
* Mon Aug  8 2005 schubi@suse.de
- Added CS translations
* Fri Aug  5 2005 meissner@suse.de
- fix pam_mktemp to compile on ppc64 (add another evil
  hack on top of the evil ext2 fcntl hack)
* Fri Jul 29 2005 schubi@suse.de
- Added proof readed text ( patch )
* Tue Jul 19 2005 lnussel@suse.de
- update resmgr module to current SVN snapshot
* Mon Jun 27 2005 kukuk@suse.de
- Update to pam_pwcheck 3.0 (Add localisation support)
* Thu Jun 23 2005 kukuk@suse.de
- Update to pam_pwcheck 2.12 (Fix cracklib default dict path
  handling)
* Fri Apr 29 2005 kukuk@suse.de
- Remove pam_selinux module (will be merged with Linux-PAM)
* Mon Mar 21 2005 schubi@suse.de
- added /dev/devperms into /etc/logindevperm Bug 73630
* Wed Mar  9 2005 schubi@suse.de
- added /dev/radio /dev/lirc to /etc/logindevperm Bug 63854
* Wed Jan 12 2005 kukuk@suse.de
- Update to pam_unix2 1.26 (fix memory leak)
- Update to pam_pwcheck 2.11 (fix memory leak)
* Mon Jan 10 2005 kukuk@suse.de
- Update to pam_wheel 1.3 (fix memory leak)
* Mon Jan  3 2005 kukuk@suse.de
- Update to pam_unix2 1.25 [#49269]
* Mon Sep 27 2004 kukuk@suse.de
- Update to pam_pwcheck 2.10 (read /etc/default/passwd) [#46242]
* Mon Sep 20 2004 kukuk@suse.de
- Update to pam_unix2 1.14 to fix [Bug #45531] partially
* Tue Sep 14 2004 kukuk@suse.de
- Add workaround for incompatible udev behavior [Bug #45204]
* Fri Aug 20 2004 kukuk@suse.de
- Update to pam_wheel 1.1
* Thu Aug 19 2004 kukuk@suse.de
- Add pam_wheel 1.0 (a real reentrant version)
* Wed Aug 18 2004 kukuk@suse.de
- Use reentrant getpw* functions in pam_passwdqc
* Tue Jul 27 2004 kukuk@suse.de
- Update to pam_unix2-1.23 (use different crypt hashes for
  different services)
* Tue May 18 2004 kukuk@suse.de
- Remove global nullok (services, which needs it have it local)
* Mon May 17 2004 kukuk@suse.de
- pam_pwcheck: Fix problem that md5 and blowfish passwords will
  be truncated after 8 characters
* Mon Apr 19 2004 kukuk@suse.de
- pam_selinux: Sync with upstream version
* Fri Mar 26 2004 kukuk@suse.de
- pam_pwcheck: Update to 2.8 [Bug #36744]
- pam_unix2: Fix valid user checking in session handling
* Mon Mar 22 2004 adrian@suse.de
- call dlopen.sh via sh
* Sat Mar 20 2004 adrian@suse.de
- add /dev/pilot to logindevperm. it is needed for PalmOS devices
  connected via serial port.
* Fri Mar 19 2004 kukuk@suse.de
- Update pam_unix2 to version 1.22 (changes for PAM test suite)
- Update pam_pwcheck to version 2.7 (fix sanity check)
* Sat Mar 13 2004 kukuk@suse.de
- Update pam_unix2 to version 1.21 (read /etc/default/passwd)
- Update pam_pwcheck to version 2.6 (fix one more memory leak)
* Mon Mar  1 2004 kukuk@suse.de
- Adjust pam_devperm boot script
* Mon Feb 23 2004 kukuk@suse.de
- Fix some memory leaks
* Fri Feb 20 2004 kukuk@suse.de
- Add pam_resmgr Module
- Don't link static against libselinux
* Mon Feb  2 2004 kukuk@suse.de
- Update pam_selinux module
* Wed Jan 28 2004 kukuk@suse.de
- Update pam_selinux module
* Fri Jan 16 2004 kukuk@suse.de
- Build as user
- Add pam-devel to neededforbuild
* Tue Dec  9 2003 ro@suse.de
- unix_chkpwd.8 removed (now in pam package)
* Mon Dec  1 2003 kukuk@suse.de
- Update pam_mktemp, pam_passwdqc and pam_userpass
- Fix all compiler warnings
- Update pam_unix2 to 1.19 (SELinux support)
* Thu Oct 30 2003 kukuk@suse.de
- Add check, if all PAM modules are loadable
- Update pam_passwdqc and pam_userpass
* Mon Sep 15 2003 kukuk@suse.de
- Don't print error message for empty arguments.
* Mon Sep  8 2003 kukuk@suse.de
- Add password hook for called modules, too, to avoid entering
  password twice in chfn/chsh.
* Mon Sep  1 2003 kukuk@suse.de
- Fix calling arguments for dlopened pam module [Bug #29592]
* Fri Aug 29 2003 tiwai@suse.de
- added the device files for ALSA to logindevperm.
  (they are now static files.)
* Fri Aug 29 2003 kukuk@suse.de
- Fix call_module handling for pam_krb5 [Bug #29287]
* Wed Jul 30 2003 kukuk@suse.de
- pam_pwcheck: Update to 2.4 (don't free global PAM data)
* Tue Jul 15 2003 kukuk@suse.de
- pam_pwcheck: Update to 2.3
- pam_unix2: Update to 1.18 (Some fixes for krb5 support)
* Mon Jul 14 2003 kukuk@suse.de
- pam_unix2: Update to version 1.17 (final call_modules option)
* Mon Jun 30 2003 kukuk@suse.de
- Fix persmission of /etc/logindevperm
- Add call_module patch to pam_unix2
* Tue May 27 2003 ro@suse.de
- added cracklib-devel to neededforbuild
* Tue May 13 2003 kukuk@suse.de
- Add missing rc_status to collect all results [Bug #26528]
* Tue May 13 2003 kukuk@suse.de
- Fix installation of manual pages
* Mon May 12 2003 kukuk@suse.de
- Update pam_unix2 and pam_pwcheck (allow password expiration of
  root account)
- Add unix_chkpwd and unix2_chkpwd manual pages
* Tue Mar 11 2003 kukuk@suse.de
- Add /dev/video1394 and /dev/raw1394 [Bug #25105]
* Fri Feb 21 2003 kukuk@suse.de
- Update pam_pwcheck to 2.1 (allow blowfish passwords with more
  than 8 characters)
* Mon Feb 10 2003 kukuk@suse.de
- Update pam_unix2 to 1.15 (abort if user press Ctrl-D)
* Thu Jan 16 2003 kukuk@suse.de
- Add pam_mktemp and pam_userpass
* Wed Jan 15 2003 kukuk@suse.de
- Update pam_pwcheck to 2.0 and pam_unix2 to 1.14. This allows
  root to change the password for other NIS user again. root is
  now also able to modify passwd/shadow source files for NIS on a
  NIS master server.
* Thu Dec 12 2002 kukuk@suse.de
- Update pam_passwdqc to 0.7
- Add READMEs about blowfish, cracklib and MD5.
- Fix location of modules on lib64 architectures
* Tue Sep 17 2002 kukuk@suse.de
- On UL1 and SLES8, make usage of cracklib default [Bug #19636]
* Sat Sep  7 2002 kukuk@suse.de
- Provide pam_devperm
* Tue Aug 27 2002 kukuk@suse.de
- Update to pam_unix2 1.12 (Bugfix for pam_ldap return code
  handling, manual page added)
* Mon Aug 26 2002 kukuk@suse.de
- Add /sbin/unix2_chkpwd [Bug #18174]
* Thu Aug 15 2002 kukuk@suse.de
- Add insserv to PreRequires
* Sat Aug 10 2002 kukuk@suse.de
- Update pam_pwcheck to 1.9
* Thu Aug  1 2002 kukuk@suse.de
- Update pam_passwdqc to version 0.6 (pam_passwdqc manual page
  added)
* Mon Jul 22 2002 kukuk@suse.de
- Update to pam_unix2 1.11 (fix detection of blowfish support)
* Thu Jul 11 2002 kukuk@suse.de
- Update to pam_pwcheck 1.8 (fix compiling with new Linux-PAM)
* Sat Jul  6 2002 kukuk@suse.de
- Use Should-Start for boot script
* Mon May 27 2002 kukuk@suse.de
- Update pam_devperm to 1.5 (Don't change group ids, add manual
  page, fix documentation).
* Tue May 21 2002 kukuk@suse.de
- Add pam_passwdqc-0.5 module
* Mon May 20 2002 kukuk@suse.de
- Update pam_unix2 (security fixes from SL 8.0 branch)
- Update pam_pwcheck (add support for remember option)
* Thu Apr 18 2002 kukuk@suse.de
- Update pam_unix2 and pam_pwcheck (Use libxcrypt instead of
  libcrypt)
* Tue Mar 12 2002 kukuk@suse.de
- Allow usernames starting with "_" for pam_devperm, too.
* Sat Mar  9 2002 kukuk@suse.de
- Update pam_unix2 to allow usernames starting with "_" [Bug #14721]
* Tue Mar  5 2002 kukuk@suse.de
- Add all usb scanner devices [Bug #14476]
- Fix path of logindevperm
* Tue Feb  5 2002 kukuk@suse.de
- Update to pam_unix2 1.7 (fix typo in config file parser)
- Update to pam_pwcheck 1.5 (Add global config file)
* Mon Feb  4 2002 kukuk@suse.de
- Fix boot init script [Bug #13003]
* Thu Jan 31 2002 grimmer@suse.de
- Added /dev/toshiba and /dev/sonypi to logindevperm to make
  laptop users happy
* Fri Jan 18 2002 kukuk@suse.de
- Update to pam_unix2 (Fix seg.fault, read config file for
  global options)
* Tue Jan 15 2002 kukuk@suse.de
- Update to pam_pwcheck 1.4 (better debug options)
- Update to pam_unix2 1.5 (load pam_ldap if necessary)
* Wed Jan  9 2002 kukuk@suse.de
- Update pam_unix2 to fix crypt problems
* Mon Jan  7 2002 kukuk@suse.de
- Big update to allow blowfish crypt
- Add pam_crypt
- Add pam_make
* Thu Dec 13 2001 kukuk@suse.de
- Add program to recover device permissions after crash [Bug #12232]
* Wed Dec 12 2001 kukuk@suse.de
- Make lib64 ready
* Wed Nov 28 2001 kukuk@suse.de
- Add /dev/gps to /etc/logindevperm
* Mon Nov 12 2001 kukuk@suse.de
- Create link for pam_unix.so
* Fri Nov  9 2001 kukuk@suse.de
- Initial version, split from pam package
